@@ -1,17 +1,13 @@
-import tempfile
 import textwrap
 from abc import ABC
 from abc import abstractmethod
 from dataclasses import dataclass
 from dataclasses import field
-from pathlib import Path
-from tempfile import NamedTemporaryFile
 from typing import Any
 from typing import Dict
 from typing import Optional
 from typing import Type
 
-import orjson as json
 from tabulate import tabulate
 from tortoise.models import Model
 
@@ -36,35 +32,6 @@ def format_help(help: str) -> str:
     return tab + unindent(help) + '\n'
 
 
-def save_crashdump(error: Exception) -> str:
-    """Saves a crashdump file with Sentry error data, returns the path to the tempfile"""
-    # NOTE: Lazy import to speed up startup
-    import sentry_sdk.serializer
-    import sentry_sdk.utils
-
-    exc_info = sentry_sdk.utils.exc_info_from_error(error)
-    event, _ = sentry_sdk.utils.event_from_exception(exc_info)
-    event = sentry_sdk.serializer.serialize(event)
-
-    tmp_dir = Path(tempfile.gettempdir()) / 'dipdup' / 'crashdumps'
-    tmp_dir.mkdir(parents=True, exist_ok=True)
-
-    crashdump_file = NamedTemporaryFile(
-        mode='ab',
-        suffix='.json',
-        dir=tmp_dir,
-        delete=False,
-    )
-    with crashdump_file as f:
-        f.write(
-            json.dumps(
-                event,
-                option=json.OPT_INDENT_2,
-            ),
-        )
-    return crashdump_file.name
-
-
 class FrameworkException(AssertionError, RuntimeError):
     pass
 
